package com.datacloudsec.scan.service.impl;

import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.dao.BugsMapper;
import com.datacloudsec.scan.entity.User;
import com.datacloudsec.scan.service.IBugs;
import com.datacloudsec.utils.DataRule;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.ObjectUtil;
import java.io.File;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpSession;
import org.apache.commons.lang.StringUtils;
import org.dom4j.Document;
import org.dom4j.Element;
import org.dom4j.io.SAXReader;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/BugsService.class */
public class BugsService implements IBugs {
    private BugsMapper bugsMapper = (BugsMapper) InstanceUtil.newDaoInstance(BugsMapper.class);

    public int searchCount(HttpSession session, String name, String level, Date published, String cnnvd, String cve) throws Exception {
        return this.bugsMapper.searchCount(name, level, published, cnnvd, cve, DataRule.getRuleWhere(session, "t_bugs"));
    }

    public List<Map<String, Object>> search(HttpSession session, String name, String level, Date published, String cnnvd, String cve, Integer offset, Integer limit) throws Exception {
        return this.bugsMapper.search(name, level, published, cnnvd, cve, offset, limit, DataRule.getRuleWhere(session, "t_bugs"));
    }

    public void delete(HttpSession session, Integer id, Integer version) throws Exception {
        Integer vcount = Integer.valueOf(this.bugsMapper.delete(id, version, DataRule.getRuleWhere(session, "t_bugs")));
        if (vcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
    }

    public void insert(HttpSession session, String name, String level, Float cvss, String cve, String cnnvd, Date published, String desct, String advice, String refs, String bid) throws Exception {
        if (this.bugsMapper.bugCountByName(name) > 0) {
            throw new UEException("漏洞【" + name + "】已存在");
        }
        User u = (User) session.getAttribute("userInfo");
        this.bugsMapper.insert(name, level, cvss, cve, cnnvd, published, desct, advice, refs, bid, u.getId());
    }

    public void update(HttpSession session, Integer id, String name, String hide_name, String level, Float cvss, String cve, String cnnvd, Date published, String desct, String advice, String refs, String bid, Integer version) throws Exception {
        if (!name.equals(hide_name) && this.bugsMapper.bugCountByName(name) > 0) {
            throw new UEException("漏洞【" + name + "】已存在");
        }
        User u = (User) session.getAttribute("userInfo");
        this.bugsMapper.update(id, name, level, cvss, cve, cnnvd, published, desct, advice, refs, bid, version, DataRule.getRuleWhere(session, "t_bugs"), u.getId());
    }

    public Map<String, Object> getBugsById(Integer id) throws Exception {
        return this.bugsMapper.getBugsById(id);
    }

    public void bugsImp(File f, HttpSession session) throws Exception {
        SAXReader reader = new SAXReader();
        Document document = reader.read(f);
        Element result = document.getRootElement();
        List<Element> entrys = result.elements();
        User u = (User) session.getAttribute("userInfo");
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        for (Element entry : entrys) {
            String name = entry.element("name").getText();
            if (!StringUtils.isBlank(name) && this.bugsMapper.bugCountByName(name) <= 0) {
                String cnnvd = entry.element("vuln-id").getText();
                String published = entry.element("published").getText();
                String level = entry.element("severity").getText();
                String desct = entry.element("vuln-descript").getText();
                String advice = entry.element("vuln-solution").getText();
                Element otherEle = entry.element("other-id");
                List<Element> others = otherEle.elements();
                List<String> cves = new ArrayList<>();
                List<String> bids = new ArrayList<>();
                for (Element other : others) {
                    if ("cve-id".equalsIgnoreCase(other.getName())) {
                        String cve = ObjectUtil.getString(other.getText(), "");
                        if (StringUtils.isNotBlank(cve) && !"null".equalsIgnoreCase(cve)) {
                            cves.add(cve);
                        }
                    } else if ("bugtraq-id".equals(other.getName())) {
                        String bid = ObjectUtil.getString(other.getText(), "");
                        if (StringUtils.isNotBlank(bid) && !"null".equalsIgnoreCase(bid)) {
                            bids.add(bid);
                        }
                    }
                }
                Element refRoot = entry.element("refs");
                List<Element> refs = refRoot.elements();
                List<String> urls = new ArrayList<>();
                for (Element ref : refs) {
                    urls.add(ref.element("ref-url").getText());
                }
                this.bugsMapper.insert(name, (String) BUG_LEVEL.get(level), (Float) null, (cves == null || cves.size() == 0) ? null : StringUtils.join(cves, ","), cnnvd, sdf.parse(published), desct, advice, (urls == null || urls.size() == 0) ? null : StringUtils.join(urls, ","), (bids == null || bids.size() == 0) ? null : StringUtils.join(bids, ","), u.getId());
            }
        }
    }
}
